@@ -6,7 +6,7 @@ use vars qw[$VERSION %utilities];
 use Module::CoreList;
 use Module::CoreList::TieHashDelta;
 
-$VERSION = '5.20141020';
+$VERSION = '5.20141220';
 
 sub utilities {
     my $perl = shift;
@@ -985,6 +985,20 @@ my %delta = (
         removed => {
         }
     },
+    5.021006 => {
+        delta_from => 5.021005,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.021007 => {
+        delta_from => 5.021006,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 for my $version (sort { $a <=> $b } keys %delta) {
